==> matchprobes_1.0.8.tar.gz: matchprobes/man/combineAffyBatch.Rd <==
\name{combineAffyBatch}
\alias{combineAffyBatch}
\title{A function to combine data from different Affymetrix genechip types
  into one AffyBatch.}
\description{
  The function takes a list of AffyBatches and their respective probe
  sequence information and merges the intensities from the matching probes
  only into one AffyBatch.}
\usage{
combineAffyBatch(batch, probepkg, newcdf, verbose=TRUE)
}
\arguments{
  \item{batch}{A \code{list} of AffyBatches.}
  \item{probepkg}{A character vector of the same length as \code{batch}, containing the names
    of the probe sequences libraries (for example, \code{hgu133aprobe})
    that go with the AffyBatches.}
  \item{newcdf}{Character. The name of the name CDF environment that is to be created.}
  \item{verbose}{Logical. If TRUE, messages are printed to the console.}
}
\details{
  Note that batch effects may play an important role, e.g. because
  of slightly but systematically different reagents or sample
  treatments in the experiments at led to the data in the different
  AffyBatches. Thus, please interprete the results of this function
  with caution.
  
  Probe to probe-set mapping: after the common probes between all
  AffyBatches have been identified, their mapping into probe sets (=the
  new CDF environment) is obtained from the restriction of the mapping
  of the first element of \code{batch} (see variable \code{REFCHIP} in the
  code).
  
  If you want to use this function, please have a look at its code
  and if necessary, check intermediate results.
}
\value{
  A list with two elements: \code{dat}, an \code{\link{AffyBatch}}, and
  \code{cdf}, an environment that contains the probe-set to probe
  mapping.

  The phenoData slot of \code{dat} will be empty. This is because
  in most cases this requires some manual interference.
  You will need to construct a combined phenoData slot by yourself.
}
\author{R. Gentleman, Wolfgang Huber}


\examples{
  ## see vignette!
}
\keyword{manip}

==> matchprobes_1.4.0.tar.gz: matchprobes/man/combineAffyBatch.Rd <==
\name{combineAffyBatch}
\alias{combineAffyBatch}
\title{A function to combine data from different Affymetrix genechip types
  into one AffyBatch.}
\description{
  The function takes a list of AffyBatches and their respective probe
  sequence information and merges the intensities from the matching probes
  only into one AffyBatch.}
\usage{
combineAffyBatch(batch, probepkg, newcdf, verbose=TRUE)
}
\arguments{
  \item{batch}{A \code{list} of AffyBatches.}
  \item{probepkg}{A character vector of the same length as \code{batch}, containing the names
    of the probe sequences libraries (for example, \code{hgu133aprobe})
    that go with the AffyBatches.}
  \item{newcdf}{Character. The name of the name CDF environment that is to be created.}
  \item{verbose}{Logical. If TRUE, messages are printed to the console.}
}
\details{
  Note that batch effects may play an important role, e.g. because
  of slightly but systematically different reagents or sample
  treatments in the experiments at led to the data in the different
  AffyBatches. Thus, please interprete the results of this function
  with caution.
  
  Probe to probe-set mapping: after the common probes between all
  AffyBatches have been identified, their mapping into probe sets (=the
  new CDF environment) is obtained from the restriction of the mapping
  of the first element of \code{batch} (see variable \code{REFCHIP} in the
  code).
  
  If you want to use this function, please have a look at its code
  and if necessary, check intermediate results.
}
\value{
  A list with two elements: \code{dat}, an \code{\link[affy]{AffyBatch}}, and
  \code{cdf}, an environment that contains the probe-set to probe
  mapping.

  The phenoData slot of \code{dat} will be empty. This is because
  in most cases this requires some manual interference.
  You will need to construct a combined phenoData slot by yourself.
}
\author{R. Gentleman, Wolfgang Huber}


\examples{
  ## see vignette!
}
\keyword{manip}
